/* seahorse-pkcs11.h generated by valac 0.20.1, the Vala compiler, do not modify */


#ifndef __SEAHORSE_PKCS11_H__
#define __SEAHORSE_PKCS11_H__

#include <glib.h>
#include <glib-object.h>
#include <seahorse-common.h>
#include <gcr/gcr-base.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS


#define SEAHORSE_TYPE_CERTIFICATE_DER_EXPORTER (seahorse_certificate_der_exporter_get_type ())
#define SEAHORSE_CERTIFICATE_DER_EXPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SEAHORSE_TYPE_CERTIFICATE_DER_EXPORTER, SeahorseCertificateDerExporter))
#define SEAHORSE_CERTIFICATE_DER_EXPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SEAHORSE_TYPE_CERTIFICATE_DER_EXPORTER, SeahorseCertificateDerExporterClass))
#define SEAHORSE_IS_CERTIFICATE_DER_EXPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SEAHORSE_TYPE_CERTIFICATE_DER_EXPORTER))
#define SEAHORSE_IS_CERTIFICATE_DER_EXPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SEAHORSE_TYPE_CERTIFICATE_DER_EXPORTER))
#define SEAHORSE_CERTIFICATE_DER_EXPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SEAHORSE_TYPE_CERTIFICATE_DER_EXPORTER, SeahorseCertificateDerExporterClass))

typedef struct _SeahorseCertificateDerExporter SeahorseCertificateDerExporter;
typedef struct _SeahorseCertificateDerExporterClass SeahorseCertificateDerExporterClass;
typedef struct _SeahorseCertificateDerExporterPrivate SeahorseCertificateDerExporterPrivate;

struct _SeahorseCertificateDerExporter {
	GObject parent_instance;
	SeahorseCertificateDerExporterPrivate * priv;
};

struct _SeahorseCertificateDerExporterClass {
	GObjectClass parent_class;
};


GType seahorse_certificate_der_exporter_get_type (void) G_GNUC_CONST;
SeahorseCertificateDerExporter* seahorse_certificate_der_exporter_new (GcrCertificate* certificate);
SeahorseCertificateDerExporter* seahorse_certificate_der_exporter_construct (GType object_type, GcrCertificate* certificate);
#define SEAHORSE_PKCS11_NAME "pkcs11"


G_END_DECLS

#endif
