/* gkr-dialogs.c generated by valac 0.20.1.64-fa28c, the Vala compiler
 * generated from gkr-dialogs.vala, do not modify */

/*
 * Seahorse
 *
 * Copyright (C) 2009 Stefan Walter
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#include <glib.h>
#include <glib-object.h>
#include "seahorse-gkr.h"
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk/gdk.h>
#include <gobject/gvaluecollector.h>

#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _SeahorseGkrParamSpecDialog SeahorseGkrParamSpecDialog;

struct _SeahorseGkrParamSpecDialog {
	GParamSpec parent_instance;
};


static gpointer seahorse_gkr_dialog_parent_class = NULL;

enum  {
	SEAHORSE_GKR_DIALOG_DUMMY_PROPERTY
};
static void seahorse_gkr_dialog_update_wait_cursor (GtkWidget* widget);
static void __lambda6_ (void* data);
static void ___lambda6__gdestroy_notify (void* data);
static void _seahorse_gkr_dialog_update_wait_cursor_gtk_widget_realize (GtkWidget* _sender, gpointer self);
static void seahorse_gkr_dialog_finalize (SeahorseGkrDialog* obj);


static gpointer _g_object_ref0 (gpointer self) {
#line 28 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	return self ? g_object_ref (self) : NULL;
#line 57 "gkr-dialogs.c"
}


static void seahorse_gkr_dialog_update_wait_cursor (GtkWidget* widget) {
	GCancellable* cancellable = NULL;
	GtkWidget* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GdkCursor* cursor = NULL;
	GtkWidget* _tmp6_ = NULL;
	gconstpointer _tmp7_ = NULL;
	GdkCursor* _tmp8_ = NULL;
	GdkCursor* _tmp9_ = NULL;
	GtkWidget* _tmp14_ = NULL;
	GdkWindow* _tmp15_ = NULL;
	GdkCursor* _tmp16_ = NULL;
#line 27 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	g_return_if_fail (widget != NULL);
#line 28 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp0_ = widget;
#line 28 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "gkr-request");
#line 28 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp2_ = _g_object_ref0 ((GCancellable*) _tmp1_);
#line 28 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	cancellable = _tmp2_;
#line 31 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp3_ = cancellable;
#line 31 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (_tmp3_ == NULL) {
#line 89 "gkr-dialogs.c"
		GtkWidget* _tmp4_ = NULL;
		GdkWindow* _tmp5_ = NULL;
#line 32 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp4_ = widget;
#line 32 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp5_ = gtk_widget_get_window (_tmp4_);
#line 32 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		gdk_window_set_cursor (_tmp5_, NULL);
#line 33 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_g_object_unref0 (cancellable);
#line 33 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		return;
#line 102 "gkr-dialogs.c"
	}
#line 40 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp6_ = widget;
#line 40 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp7_ = g_object_get_data ((GObject*) _tmp6_, "wait-cursor");
#line 40 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp8_ = _g_object_ref0 ((GdkCursor*) _tmp7_);
#line 40 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	cursor = _tmp8_;
#line 41 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp9_ = cursor;
#line 41 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (_tmp9_ == NULL) {
#line 116 "gkr-dialogs.c"
		GdkCursor* _tmp10_ = NULL;
		GtkWidget* _tmp11_ = NULL;
		GdkCursor* _tmp12_ = NULL;
		GdkCursor* _tmp13_ = NULL;
#line 42 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp10_ = gdk_cursor_new (GDK_WATCH);
#line 42 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_g_object_unref0 (cursor);
#line 42 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		cursor = _tmp10_;
#line 43 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp11_ = widget;
#line 43 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp12_ = cursor;
#line 43 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp13_ = _g_object_ref0 (_tmp12_);
#line 43 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		g_object_set_data_full ((GObject*) _tmp11_, "wait-cursor", _tmp13_, g_object_unref);
#line 135 "gkr-dialogs.c"
	}
#line 47 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp14_ = widget;
#line 47 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp15_ = gtk_widget_get_window (_tmp14_);
#line 47 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp16_ = cursor;
#line 47 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	gdk_window_set_cursor (_tmp15_, _tmp16_);
#line 27 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_g_object_unref0 (cursor);
#line 27 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_g_object_unref0 (cancellable);
#line 149 "gkr-dialogs.c"
}


static void __lambda6_ (void* data) {
	GCancellable* c = NULL;
	void* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
#line 60 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp0_ = data;
#line 60 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, g_cancellable_get_type (), GCancellable));
#line 60 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	c = _tmp1_;
#line 61 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	g_cancellable_cancel (c);
#line 62 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	g_object_unref ((GObject*) c);
#line 59 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_g_object_unref0 (c);
#line 169 "gkr-dialogs.c"
}


static void ___lambda6__gdestroy_notify (void* data) {
#line 59 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	__lambda6_ (data);
#line 176 "gkr-dialogs.c"
}


static void _seahorse_gkr_dialog_update_wait_cursor_gtk_widget_realize (GtkWidget* _sender, gpointer self) {
#line 68 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	seahorse_gkr_dialog_update_wait_cursor (_sender);
#line 183 "gkr-dialogs.c"
}


GCancellable* seahorse_gkr_dialog_begin_request (GtkWidget* dialog) {
	GCancellable* result = NULL;
	GtkWidget* _tmp0_ = NULL;
	GCancellable* cancellable = NULL;
	GCancellable* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GObject* _tmp4_ = NULL;
	GtkWidget* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	GtkWidget* _tmp9_ = NULL;
#line 50 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	g_return_val_if_fail (dialog != NULL, NULL);
#line 52 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp0_ = dialog;
#line 52 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	seahorse_gkr_dialog_complete_request (_tmp0_, TRUE);
#line 58 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp1_ = g_cancellable_new ();
#line 58 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	cancellable = _tmp1_;
#line 59 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp2_ = dialog;
#line 59 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp3_ = cancellable;
#line 59 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp4_ = g_object_ref ((GObject*) _tmp3_);
#line 59 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	g_object_set_data_full ((GObject*) _tmp2_, "gkr-request", _tmp4_, ___lambda6__gdestroy_notify);
#line 65 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp5_ = dialog;
#line 65 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp6_ = gtk_widget_get_realized (_tmp5_);
#line 65 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (_tmp6_) {
#line 222 "gkr-dialogs.c"
		GtkWidget* _tmp7_ = NULL;
#line 66 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp7_ = dialog;
#line 66 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		seahorse_gkr_dialog_update_wait_cursor (_tmp7_);
#line 228 "gkr-dialogs.c"
	} else {
		GtkWidget* _tmp8_ = NULL;
#line 68 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp8_ = dialog;
#line 68 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		g_signal_connect (_tmp8_, "realize", (GCallback) _seahorse_gkr_dialog_update_wait_cursor_gtk_widget_realize, NULL);
#line 235 "gkr-dialogs.c"
	}
#line 70 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp9_ = dialog;
#line 70 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	gtk_widget_set_sensitive (_tmp9_, FALSE);
#line 71 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	result = cancellable;
#line 71 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	return result;
#line 245 "gkr-dialogs.c"
}


void seahorse_gkr_dialog_complete_request (GtkWidget* dialog, gboolean cancel) {
	GCancellable* cancellable = NULL;
	GtkWidget* _tmp0_ = NULL;
	gpointer _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GCancellable* _tmp3_ = NULL;
	gboolean _tmp5_ = FALSE;
	GtkWidget* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	GtkWidget* _tmp10_ = NULL;
#line 74 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	g_return_if_fail (dialog != NULL);
#line 75 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp0_ = dialog;
#line 75 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp1_ = g_object_steal_data ((GObject*) _tmp0_, "gkr-request");
#line 75 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	cancellable = (GCancellable*) _tmp1_;
#line 76 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp3_ = cancellable;
#line 76 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (_tmp3_ != NULL) {
#line 271 "gkr-dialogs.c"
		gboolean _tmp4_ = FALSE;
#line 76 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp4_ = cancel;
#line 76 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp2_ = _tmp4_;
#line 277 "gkr-dialogs.c"
	} else {
#line 76 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp2_ = FALSE;
#line 281 "gkr-dialogs.c"
	}
#line 76 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp5_ = _tmp2_;
#line 76 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (_tmp5_) {
#line 287 "gkr-dialogs.c"
		GCancellable* _tmp6_ = NULL;
#line 77 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp6_ = cancellable;
#line 77 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		g_cancellable_cancel (_tmp6_);
#line 293 "gkr-dialogs.c"
	}
#line 78 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp7_ = dialog;
#line 78 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp8_ = gtk_widget_get_realized (_tmp7_);
#line 78 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (_tmp8_) {
#line 301 "gkr-dialogs.c"
		GtkWidget* _tmp9_ = NULL;
#line 79 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		_tmp9_ = dialog;
#line 79 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		seahorse_gkr_dialog_update_wait_cursor (_tmp9_);
#line 307 "gkr-dialogs.c"
	}
#line 80 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_tmp10_ = dialog;
#line 80 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	gtk_widget_set_sensitive (_tmp10_, TRUE);
#line 74 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	_g_object_unref0 (cancellable);
#line 315 "gkr-dialogs.c"
}


SeahorseGkrDialog* seahorse_gkr_dialog_construct (GType object_type) {
	SeahorseGkrDialog* self = NULL;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	self = (SeahorseGkrDialog*) g_type_create_instance (object_type);
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	return self;
#line 325 "gkr-dialogs.c"
}


SeahorseGkrDialog* seahorse_gkr_dialog_new (void) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	return seahorse_gkr_dialog_construct (SEAHORSE_GKR_TYPE_DIALOG);
#line 332 "gkr-dialogs.c"
}


static void seahorse_gkr_value_dialog_init (GValue* value) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 339 "gkr-dialogs.c"
}


static void seahorse_gkr_value_dialog_free_value (GValue* value) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (value->data[0].v_pointer) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		seahorse_gkr_dialog_unref (value->data[0].v_pointer);
#line 348 "gkr-dialogs.c"
	}
}


static void seahorse_gkr_value_dialog_copy_value (const GValue* src_value, GValue* dest_value) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		dest_value->data[0].v_pointer = seahorse_gkr_dialog_ref (src_value->data[0].v_pointer);
#line 358 "gkr-dialogs.c"
	} else {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 362 "gkr-dialogs.c"
	}
}


static gpointer seahorse_gkr_value_dialog_peek_pointer (const GValue* value) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	return value->data[0].v_pointer;
#line 370 "gkr-dialogs.c"
}


static gchar* seahorse_gkr_value_dialog_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 377 "gkr-dialogs.c"
		SeahorseGkrDialog* object;
		object = collect_values[0].v_pointer;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 384 "gkr-dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 388 "gkr-dialogs.c"
		}
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		value->data[0].v_pointer = seahorse_gkr_dialog_ref (object);
#line 392 "gkr-dialogs.c"
	} else {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 396 "gkr-dialogs.c"
	}
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	return NULL;
#line 400 "gkr-dialogs.c"
}


static gchar* seahorse_gkr_value_dialog_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	SeahorseGkrDialog** object_p;
	object_p = collect_values[0].v_pointer;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (!object_p) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 411 "gkr-dialogs.c"
	}
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		*object_p = NULL;
#line 417 "gkr-dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 421 "gkr-dialogs.c"
	} else {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		*object_p = seahorse_gkr_dialog_ref (value->data[0].v_pointer);
#line 425 "gkr-dialogs.c"
	}
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	return NULL;
#line 429 "gkr-dialogs.c"
}


GParamSpec* seahorse_gkr_param_spec_dialog (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	SeahorseGkrParamSpecDialog* spec;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, SEAHORSE_GKR_TYPE_DIALOG), NULL);
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 443 "gkr-dialogs.c"
}


gpointer seahorse_gkr_value_get_dialog (const GValue* value) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, SEAHORSE_GKR_TYPE_DIALOG), NULL);
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	return value->data[0].v_pointer;
#line 452 "gkr-dialogs.c"
}


void seahorse_gkr_value_set_dialog (GValue* value, gpointer v_object) {
	SeahorseGkrDialog* old;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, SEAHORSE_GKR_TYPE_DIALOG));
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	old = value->data[0].v_pointer;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (v_object) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, SEAHORSE_GKR_TYPE_DIALOG));
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		seahorse_gkr_dialog_ref (value->data[0].v_pointer);
#line 472 "gkr-dialogs.c"
	} else {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 476 "gkr-dialogs.c"
	}
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (old) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		seahorse_gkr_dialog_unref (old);
#line 482 "gkr-dialogs.c"
	}
}


void seahorse_gkr_value_take_dialog (GValue* value, gpointer v_object) {
	SeahorseGkrDialog* old;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, SEAHORSE_GKR_TYPE_DIALOG));
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	old = value->data[0].v_pointer;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (v_object) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, SEAHORSE_GKR_TYPE_DIALOG));
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 501 "gkr-dialogs.c"
	} else {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 505 "gkr-dialogs.c"
	}
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (old) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		seahorse_gkr_dialog_unref (old);
#line 511 "gkr-dialogs.c"
	}
}


static void seahorse_gkr_dialog_class_init (SeahorseGkrDialogClass * klass) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	seahorse_gkr_dialog_parent_class = g_type_class_peek_parent (klass);
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	SEAHORSE_GKR_DIALOG_CLASS (klass)->finalize = seahorse_gkr_dialog_finalize;
#line 521 "gkr-dialogs.c"
}


static void seahorse_gkr_dialog_instance_init (SeahorseGkrDialog * self) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	self->ref_count = 1;
#line 528 "gkr-dialogs.c"
}


static void seahorse_gkr_dialog_finalize (SeahorseGkrDialog* obj) {
	SeahorseGkrDialog * self;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SEAHORSE_GKR_TYPE_DIALOG, SeahorseGkrDialog);
#line 536 "gkr-dialogs.c"
}


GType seahorse_gkr_dialog_get_type (void) {
	static volatile gsize seahorse_gkr_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&seahorse_gkr_dialog_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { seahorse_gkr_value_dialog_init, seahorse_gkr_value_dialog_free_value, seahorse_gkr_value_dialog_copy_value, seahorse_gkr_value_dialog_peek_pointer, "p", seahorse_gkr_value_dialog_collect_value, "p", seahorse_gkr_value_dialog_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (SeahorseGkrDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) seahorse_gkr_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SeahorseGkrDialog), 0, (GInstanceInitFunc) seahorse_gkr_dialog_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType seahorse_gkr_dialog_type_id;
		seahorse_gkr_dialog_type_id = g_type_register_fundamental (g_type_fundamental_next (), "SeahorseGkrDialog", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&seahorse_gkr_dialog_type_id__volatile, seahorse_gkr_dialog_type_id);
	}
	return seahorse_gkr_dialog_type_id__volatile;
}


gpointer seahorse_gkr_dialog_ref (gpointer instance) {
	SeahorseGkrDialog* self;
	self = instance;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	return instance;
#line 561 "gkr-dialogs.c"
}


void seahorse_gkr_dialog_unref (gpointer instance) {
	SeahorseGkrDialog* self;
	self = instance;
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		SEAHORSE_GKR_DIALOG_GET_CLASS (self)->finalize (self);
#line 25 "/data/projects/seahorse/gkr/gkr-dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 574 "gkr-dialogs.c"
	}
}



