/* backend.c generated by valac 0.20.1.64-fa28c, the Vala compiler
 * generated from backend.vala, do not modify */

/*
 * Seahorse
 *
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <glib.h>
#include <glib-object.h>
#include "seahorse-internal.h"
#include <stdlib.h>
#include <string.h>






SeahorsePlace* seahorse_backend_lookup_place (SeahorseBackend* self, const gchar* uri) {
#line 30 "/data/projects/seahorse/common/backend.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 30 "/data/projects/seahorse/common/backend.vala"
	return SEAHORSE_BACKEND_GET_INTERFACE (self)->lookup_place (self, uri);
#line 42 "backend.c"
}


void seahorse_backend_register (SeahorseBackend* self) {
#line 33 "/data/projects/seahorse/common/backend.vala"
	seahorse_registry_register_object ((GObject*) self, "backend");
#line 49 "backend.c"
}


GList* seahorse_backend_get_registered (void) {
	GList* result = NULL;
	GList* _tmp0_ = NULL;
#line 37 "/data/projects/seahorse/common/backend.vala"
	_tmp0_ = seahorse_registry_object_instances ("backend");
#line 37 "/data/projects/seahorse/common/backend.vala"
	result = (GList*) _tmp0_;
#line 37 "/data/projects/seahorse/common/backend.vala"
	return result;
#line 62 "backend.c"
}


const gchar* seahorse_backend_get_name (SeahorseBackend* self) {
#line 25 "/data/projects/seahorse/common/backend.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 25 "/data/projects/seahorse/common/backend.vala"
	return SEAHORSE_BACKEND_GET_INTERFACE (self)->get_name (self);
#line 71 "backend.c"
}


const gchar* seahorse_backend_get_label (SeahorseBackend* self) {
#line 26 "/data/projects/seahorse/common/backend.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 26 "/data/projects/seahorse/common/backend.vala"
	return SEAHORSE_BACKEND_GET_INTERFACE (self)->get_label (self);
#line 80 "backend.c"
}


const gchar* seahorse_backend_get_description (SeahorseBackend* self) {
#line 27 "/data/projects/seahorse/common/backend.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 27 "/data/projects/seahorse/common/backend.vala"
	return SEAHORSE_BACKEND_GET_INTERFACE (self)->get_description (self);
#line 89 "backend.c"
}


GtkActionGroup* seahorse_backend_get_actions (SeahorseBackend* self) {
#line 28 "/data/projects/seahorse/common/backend.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 28 "/data/projects/seahorse/common/backend.vala"
	return SEAHORSE_BACKEND_GET_INTERFACE (self)->get_actions (self);
#line 98 "backend.c"
}


static void seahorse_backend_base_init (SeahorseBackendIface * iface) {
#line 24 "/data/projects/seahorse/common/backend.vala"
	static gboolean initialized = FALSE;
#line 24 "/data/projects/seahorse/common/backend.vala"
	if (!initialized) {
#line 24 "/data/projects/seahorse/common/backend.vala"
		initialized = TRUE;
#line 24 "/data/projects/seahorse/common/backend.vala"
		g_object_interface_install_property (iface, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 24 "/data/projects/seahorse/common/backend.vala"
		g_object_interface_install_property (iface, g_param_spec_string ("label", "label", "label", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 24 "/data/projects/seahorse/common/backend.vala"
		g_object_interface_install_property (iface, g_param_spec_string ("description", "description", "description", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 24 "/data/projects/seahorse/common/backend.vala"
		g_object_interface_install_property (iface, g_param_spec_object ("actions", "actions", "actions", GTK_TYPE_ACTION_GROUP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 117 "backend.c"
	}
}


GType seahorse_backend_get_type (void) {
	static volatile gsize seahorse_backend_type_id__volatile = 0;
	if (g_once_init_enter (&seahorse_backend_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SeahorseBackendIface), (GBaseInitFunc) seahorse_backend_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType seahorse_backend_type_id;
		seahorse_backend_type_id = g_type_register_static (G_TYPE_INTERFACE, "SeahorseBackend", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (seahorse_backend_type_id, gcr_collection_get_type ());
		g_once_init_leave (&seahorse_backend_type_id__volatile, seahorse_backend_type_id);
	}
	return seahorse_backend_type_id__volatile;
}



