/* gkr-keyring-properties.c generated by valac 0.20.1.64-fa28c, the Vala compiler
 * generated from gkr-keyring-properties.vala, do not modify */

/*
 * Seahorse
 *
 * Copyright (C) 2008 Stefan Walter
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the
 * Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <glib.h>
#include <glib-object.h>
#include "seahorse-gkr.h"
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <config.h>
#include <seahorse-internal.h>
#include <libsecret/secret.h>

#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

struct _SeahorseGkrKeyringPropertiesPrivate {
	SeahorseGkrKeyring* _keyring;
	GtkBuilder* _builder;
};


static gpointer seahorse_gkr_keyring_properties_parent_class = NULL;

#define SEAHORSE_GKR_KEYRING_PROPERTIES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SEAHORSE_GKR_TYPE_KEYRING_PROPERTIES, SeahorseGkrKeyringPropertiesPrivate))
enum  {
	SEAHORSE_GKR_KEYRING_PROPERTIES_DUMMY_PROPERTY,
	SEAHORSE_GKR_KEYRING_PROPERTIES_KEYRING
};
static GObject * seahorse_gkr_keyring_properties_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _seahorse_gkr_keyring_properties___lambda29_ (SeahorseGkrKeyringProperties* self, gint response);
static void __seahorse_gkr_keyring_properties___lambda29__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void _seahorse_gkr_keyring_properties___lambda30_ (SeahorseGkrKeyringProperties* self, GParamSpec* pspec);
static void __seahorse_gkr_keyring_properties___lambda30__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void seahorse_gkr_keyring_properties_finalize (GObject* obj);
static void _vala_seahorse_gkr_keyring_properties_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_seahorse_gkr_keyring_properties_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


SeahorseGkrKeyringProperties* seahorse_gkr_keyring_properties_construct (GType object_type, SeahorseGkrKeyring* keyring, GtkWindow* parent) {
	SeahorseGkrKeyringProperties * self = NULL;
	SeahorseGkrKeyring* _tmp0_ = NULL;
	GtkWindow* _tmp1_ = NULL;
#line 70 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	g_return_val_if_fail (keyring != NULL, NULL);
#line 72 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp0_ = keyring;
#line 72 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp1_ = parent;
#line 72 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	self = (SeahorseGkrKeyringProperties*) g_object_new (object_type, "keyring", _tmp0_, "transient-for", _tmp1_, NULL);
#line 70 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	return self;
#line 77 "gkr-keyring-properties.c"
}


SeahorseGkrKeyringProperties* seahorse_gkr_keyring_properties_new (SeahorseGkrKeyring* keyring, GtkWindow* parent) {
#line 70 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	return seahorse_gkr_keyring_properties_construct (SEAHORSE_GKR_TYPE_KEYRING_PROPERTIES, keyring, parent);
#line 84 "gkr-keyring-properties.c"
}


SeahorseGkrKeyring* seahorse_gkr_keyring_properties_get_keyring (SeahorseGkrKeyringProperties* self) {
	SeahorseGkrKeyring* result;
	SeahorseGkrKeyring* _tmp0_ = NULL;
#line 26 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 26 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp0_ = self->priv->_keyring;
#line 26 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	result = _tmp0_;
#line 26 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	return result;
#line 99 "gkr-keyring-properties.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 106 "gkr-keyring-properties.c"
}


static void seahorse_gkr_keyring_properties_set_keyring (SeahorseGkrKeyringProperties* self, SeahorseGkrKeyring* value) {
	SeahorseGkrKeyring* _tmp0_ = NULL;
	SeahorseGkrKeyring* _tmp1_ = NULL;
#line 26 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	g_return_if_fail (self != NULL);
#line 26 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp0_ = value;
#line 26 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 26 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_g_object_unref0 (self->priv->_keyring);
#line 26 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	self->priv->_keyring = _tmp1_;
#line 26 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	g_object_notify ((GObject *) self, "keyring");
#line 125 "gkr-keyring-properties.c"
}


static void _seahorse_gkr_keyring_properties___lambda29_ (SeahorseGkrKeyringProperties* self, gint response) {
#line 45 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	gtk_widget_destroy ((GtkWidget*) self);
#line 132 "gkr-keyring-properties.c"
}


static void __seahorse_gkr_keyring_properties___lambda29__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 44 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_seahorse_gkr_keyring_properties___lambda29_ (self, response_id);
#line 139 "gkr-keyring-properties.c"
}


static void _seahorse_gkr_keyring_properties___lambda30_ (SeahorseGkrKeyringProperties* self, GParamSpec* pspec) {
	GParamSpec* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GQuark _tmp4_ = 0U;
#line 61 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	static GQuark _tmp3_label0 = 0;
#line 60 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	g_return_if_fail (pspec != NULL);
#line 61 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp0_ = pspec;
#line 61 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp1_ = _tmp0_->name;
#line 61 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp2_ = _tmp1_;
#line 61 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp4_ = (NULL == _tmp2_) ? 0 : g_quark_from_string (_tmp2_);
#line 61 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	if (_tmp4_ == ((0 != _tmp3_label0) ? _tmp3_label0 : (_tmp3_label0 = g_quark_from_static_string ("created")))) {
#line 61 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		switch (0) {
#line 164 "gkr-keyring-properties.c"
			default:
			{
				GtkLabel* created = NULL;
				GtkBuilder* _tmp5_ = NULL;
				GObject* _tmp6_ = NULL;
				GtkLabel* _tmp7_ = NULL;
				GtkLabel* _tmp8_ = NULL;
				SeahorseGkrKeyring* _tmp9_ = NULL;
				guint64 _tmp10_ = 0ULL;
				guint64 _tmp11_ = 0ULL;
				gchar* _tmp12_ = NULL;
				gchar* _tmp13_ = NULL;
#line 63 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				_tmp5_ = self->priv->_builder;
#line 63 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				_tmp6_ = gtk_builder_get_object (_tmp5_, "created-field");
#line 63 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GTK_TYPE_LABEL, GtkLabel));
#line 63 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				created = _tmp7_;
#line 64 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				_tmp8_ = created;
#line 64 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				_tmp9_ = self->priv->_keyring;
#line 64 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				g_object_get ((SecretCollection*) _tmp9_, "created", &_tmp10_, NULL);
#line 64 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				_tmp11_ = _tmp10_;
#line 64 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				_tmp12_ = seahorse_util_get_display_date_string ((glong) _tmp11_);
#line 64 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				_tmp13_ = _tmp12_;
#line 64 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				gtk_label_set_label (_tmp8_, _tmp13_);
#line 64 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				_g_free0 (_tmp13_);
#line 65 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				_g_object_unref0 (created);
#line 65 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
				break;
#line 205 "gkr-keyring-properties.c"
			}
		}
	}
}


static void __seahorse_gkr_keyring_properties___lambda30__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 60 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_seahorse_gkr_keyring_properties___lambda30_ (self, pspec);
#line 215 "gkr-keyring-properties.c"
}


static GObject * seahorse_gkr_keyring_properties_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	SeahorseGkrKeyringProperties * self;
	GtkBuilder* _tmp0_ = NULL;
	GtkWidget* content = NULL;
	GtkBuilder* _tmp6_ = NULL;
	GObject* _tmp7_ = NULL;
	GtkWidget* _tmp8_ = NULL;
	GtkBox* _tmp9_ = NULL;
	GtkWidget* _tmp10_ = NULL;
	GtkWidget* _tmp11_ = NULL;
	SeahorseGkrKeyring* _tmp12_ = NULL;
	GtkBuilder* _tmp13_ = NULL;
	GObject* _tmp14_ = NULL;
	SeahorseGkrKeyring* _tmp15_ = NULL;
	GtkLabel* name = NULL;
	GtkBuilder* _tmp16_ = NULL;
	GObject* _tmp17_ = NULL;
	GtkLabel* _tmp18_ = NULL;
	SeahorseGkrKeyring* _tmp19_ = NULL;
	GtkLabel* _tmp20_ = NULL;
	SeahorseGkrKeyring* _tmp21_ = NULL;
	GError * _inner_error_ = NULL;
#line 30 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	parent_class = G_OBJECT_CLASS (seahorse_gkr_keyring_properties_parent_class);
#line 30 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 30 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SEAHORSE_GKR_TYPE_KEYRING_PROPERTIES, SeahorseGkrKeyringProperties);
#line 31 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp0_ = gtk_builder_new ();
#line 31 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_g_object_unref0 (self->priv->_builder);
#line 31 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	self->priv->_builder = _tmp0_;
#line 255 "gkr-keyring-properties.c"
	{
		gchar* path = NULL;
		gchar* _tmp1_ = NULL;
		GtkBuilder* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
#line 33 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		_tmp1_ = g_build_filename (UIDIR, "seahorse-gkr-keyring.xml", NULL);
#line 33 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		path = _tmp1_;
#line 34 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		_tmp2_ = self->priv->_builder;
#line 34 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		_tmp3_ = path;
#line 34 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		gtk_builder_add_from_file (_tmp2_, _tmp3_, &_inner_error_);
#line 34 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		if (_inner_error_ != NULL) {
#line 34 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
			_g_free0 (path);
#line 275 "gkr-keyring-properties.c"
			goto __catch15_g_error;
		}
#line 32 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		_g_free0 (path);
#line 280 "gkr-keyring-properties.c"
	}
	goto __finally15;
	__catch15_g_error:
	{
		GError* err = NULL;
		GError* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 32 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		err = _inner_error_;
#line 32 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		_inner_error_ = NULL;
#line 36 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		_tmp4_ = err;
#line 36 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		_tmp5_ = _tmp4_->message;
#line 36 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		g_critical ("gkr-keyring-properties.vala:36: %s", _tmp5_);
#line 32 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		_g_error_free0 (err);
#line 300 "gkr-keyring-properties.c"
	}
	__finally15:
#line 32 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	if (_inner_error_ != NULL) {
#line 32 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 32 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		g_clear_error (&_inner_error_);
#line 309 "gkr-keyring-properties.c"
	}
#line 39 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	gtk_dialog_add_button ((GtkDialog*) self, GTK_STOCK_CLOSE, (gint) GTK_RESPONSE_CLOSE);
#line 40 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp6_ = self->priv->_builder;
#line 40 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp7_ = gtk_builder_get_object (_tmp6_, "gkr-item-properties");
#line 40 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GTK_TYPE_WIDGET, GtkWidget));
#line 40 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	content = _tmp8_;
#line 41 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp9_ = (GtkBox*) gtk_dialog_get_content_area ((GtkDialog*) self);
#line 41 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp10_ = content;
#line 41 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GTK_TYPE_CONTAINER, GtkContainer), _tmp10_);
#line 42 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp11_ = content;
#line 42 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	gtk_widget_show (_tmp11_);
#line 44 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	g_signal_connect_object ((GtkDialog*) self, "response", (GCallback) __seahorse_gkr_keyring_properties___lambda29__gtk_dialog_response, self, 0);
#line 49 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp12_ = self->priv->_keyring;
#line 49 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp13_ = self->priv->_builder;
#line 49 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp14_ = gtk_builder_get_object (_tmp13_, "keyring-image");
#line 49 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp12_, "icon", _tmp14_, "gicon", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 53 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp15_ = self->priv->_keyring;
#line 53 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp15_, "label", (GObject*) self, "title", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 56 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp16_ = self->priv->_builder;
#line 56 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp17_ = gtk_builder_get_object (_tmp16_, "name-field");
#line 56 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GTK_TYPE_LABEL, GtkLabel));
#line 56 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	name = _tmp18_;
#line 57 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp19_ = self->priv->_keyring;
#line 57 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp20_ = name;
#line 57 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp19_, "label", (GObject*) _tmp20_, "label", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 60 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_tmp21_ = self->priv->_keyring;
#line 60 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	g_signal_connect_object ((GObject*) _tmp21_, "notify", (GCallback) __seahorse_gkr_keyring_properties___lambda30__g_object_notify, self, 0);
#line 30 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_g_object_unref0 (name);
#line 30 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_g_object_unref0 (content);
#line 30 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	return obj;
#line 369 "gkr-keyring-properties.c"
}


static void seahorse_gkr_keyring_properties_class_init (SeahorseGkrKeyringPropertiesClass * klass) {
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	seahorse_gkr_keyring_properties_parent_class = g_type_class_peek_parent (klass);
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	g_type_class_add_private (klass, sizeof (SeahorseGkrKeyringPropertiesPrivate));
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_seahorse_gkr_keyring_properties_get_property;
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_seahorse_gkr_keyring_properties_set_property;
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	G_OBJECT_CLASS (klass)->constructor = seahorse_gkr_keyring_properties_constructor;
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	G_OBJECT_CLASS (klass)->finalize = seahorse_gkr_keyring_properties_finalize;
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), SEAHORSE_GKR_KEYRING_PROPERTIES_KEYRING, g_param_spec_object ("keyring", "keyring", "keyring", SEAHORSE_GKR_TYPE_KEYRING, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 388 "gkr-keyring-properties.c"
}


static void seahorse_gkr_keyring_properties_instance_init (SeahorseGkrKeyringProperties * self) {
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	self->priv = SEAHORSE_GKR_KEYRING_PROPERTIES_GET_PRIVATE (self);
#line 395 "gkr-keyring-properties.c"
}


static void seahorse_gkr_keyring_properties_finalize (GObject* obj) {
	SeahorseGkrKeyringProperties * self;
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SEAHORSE_GKR_TYPE_KEYRING_PROPERTIES, SeahorseGkrKeyringProperties);
#line 26 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_g_object_unref0 (self->priv->_keyring);
#line 28 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	_g_object_unref0 (self->priv->_builder);
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	G_OBJECT_CLASS (seahorse_gkr_keyring_properties_parent_class)->finalize (obj);
#line 409 "gkr-keyring-properties.c"
}


GType seahorse_gkr_keyring_properties_get_type (void) {
	static volatile gsize seahorse_gkr_keyring_properties_type_id__volatile = 0;
	if (g_once_init_enter (&seahorse_gkr_keyring_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SeahorseGkrKeyringPropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) seahorse_gkr_keyring_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SeahorseGkrKeyringProperties), 0, (GInstanceInitFunc) seahorse_gkr_keyring_properties_instance_init, NULL };
		GType seahorse_gkr_keyring_properties_type_id;
		seahorse_gkr_keyring_properties_type_id = g_type_register_static (GTK_TYPE_DIALOG, "SeahorseGkrKeyringProperties", &g_define_type_info, 0);
		g_once_init_leave (&seahorse_gkr_keyring_properties_type_id__volatile, seahorse_gkr_keyring_properties_type_id);
	}
	return seahorse_gkr_keyring_properties_type_id__volatile;
}


static void _vala_seahorse_gkr_keyring_properties_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	SeahorseGkrKeyringProperties * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SEAHORSE_GKR_TYPE_KEYRING_PROPERTIES, SeahorseGkrKeyringProperties);
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	switch (property_id) {
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		case SEAHORSE_GKR_KEYRING_PROPERTIES_KEYRING:
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		g_value_set_object (value, seahorse_gkr_keyring_properties_get_keyring (self));
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		break;
#line 436 "gkr-keyring-properties.c"
		default:
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		break;
#line 442 "gkr-keyring-properties.c"
	}
}


static void _vala_seahorse_gkr_keyring_properties_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	SeahorseGkrKeyringProperties * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, SEAHORSE_GKR_TYPE_KEYRING_PROPERTIES, SeahorseGkrKeyringProperties);
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
	switch (property_id) {
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		case SEAHORSE_GKR_KEYRING_PROPERTIES_KEYRING:
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		seahorse_gkr_keyring_properties_set_keyring (self, g_value_get_object (value));
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		break;
#line 458 "gkr-keyring-properties.c"
		default:
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 25 "/data/projects/seahorse/gkr/gkr-keyring-properties.vala"
		break;
#line 464 "gkr-keyring-properties.c"
	}
}



