/* icons.c generated by valac 0.20.1.64-fa28c, the Vala compiler
 * generated from icons.vala, do not modify */

/*
 * Seahorse
 *
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 *
 * Author: Stef Walter <stefw@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include "seahorse-internal.h"
#include <stdlib.h>
#include <string.h>
#include <config.h>
#include <gtk/gtk.h>

#define _g_free0(var) (var = (g_free (var), NULL))


gboolean seahorse__icons_inited = FALSE;



void seahorse_icons_init (void) {
	gboolean _tmp0_ = FALSE;
	gchar* path = NULL;
	gchar* _tmp1_ = NULL;
	GtkIconTheme* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
#line 39 "/data/projects/seahorse/common/icons.vala"
	_tmp0_ = seahorse__icons_inited;
#line 39 "/data/projects/seahorse/common/icons.vala"
	if (_tmp0_) {
#line 40 "/data/projects/seahorse/common/icons.vala"
		return;
#line 55 "icons.c"
	}
#line 41 "/data/projects/seahorse/common/icons.vala"
	seahorse__icons_inited = TRUE;
#line 43 "/data/projects/seahorse/common/icons.vala"
	_tmp1_ = g_build_filename (PKGDATADIR, "icons", NULL);
#line 43 "/data/projects/seahorse/common/icons.vala"
	path = _tmp1_;
#line 44 "/data/projects/seahorse/common/icons.vala"
	_tmp2_ = gtk_icon_theme_get_default ();
#line 44 "/data/projects/seahorse/common/icons.vala"
	_tmp3_ = path;
#line 44 "/data/projects/seahorse/common/icons.vala"
	gtk_icon_theme_append_search_path (_tmp2_, _tmp3_);
#line 45 "/data/projects/seahorse/common/icons.vala"
	gtk_window_set_default_icon_name ("seahorse");
#line 38 "/data/projects/seahorse/common/icons.vala"
	_g_free0 (path);
#line 73 "icons.c"
}



